# xnote-cli
Easily keep track of your notes on your favorite terminal emulator!

# Installation:

``pip3 install xnote``

## NOTE: Only the prerelease versions work for now. Check out [the release history](https://pypi.org/project/xnote/#history) and download the latest prerelease version.